Tlačítko vložit tabulku

Tlačítko vložit tabulku | Obsah

Tlačítko vložit tabulku otevře následující okno, v němž můžete definovat novou tabulku.
Popis políček:

Sloupce | Počet sloupců v tabulce.
Řádky | Počet řádků v tabulce.
Vnitřní okraj buněk | Vnitřní okraj buněk tabulky.
Vnější okraj buněk | Vnitřní okraj buněk tabulky.
Zarovnání | Zarovnání tabulky.
Rámeček | Tloušťka rámečku tabulky.
Šířka | Šířka tabulky v pixelech.
Výška | Výška tabulky v pixelech.

Jdi na: Obsah | Nahoru